package com.ruoyi.system.service;

import com.github.pagehelper.PageInfo;
import com.ruoyi.system.domain.EpsTaskStatistics;

import java.util.List;
import java.util.Map;

/**
 * 业务95值计算任务Service接口
 *
 * @author gyt
 * @date 2025-10-29
 */
public interface IEpsTaskStatisticsService
{
    /**
     * 查询业务95值计算任务
     *
     * @param id 业务95值计算任务主键
     * @return 业务95值计算任务
     */
    public EpsTaskStatistics selectEpsTaskStatisticsById(Long id);

    /**
     * 查询业务95值计算任务列表
     *
     * @param epsTaskStatistics 业务95值计算任务
     * @return 业务95值计算任务集合
     */
    public List<EpsTaskStatistics> selectEpsTaskStatisticsList(EpsTaskStatistics epsTaskStatistics);

    /**
     * 新增业务95值计算任务
     *
     * @param epsTaskStatistics 业务95值计算任务
     * @return 结果
     */
    public int insertEpsTaskStatistics(EpsTaskStatistics epsTaskStatistics);

    /**
     * 修改业务95值计算任务
     *
     * @param epsTaskStatistics 业务95值计算任务
     * @return 结果
     */
    public int updateEpsTaskStatistics(EpsTaskStatistics epsTaskStatistics);

    /**
     * 批量删除业务95值计算任务
     *
     * @param ids 需要删除的业务95值计算任务主键集合
     * @return 结果
     */
    public int deleteEpsTaskStatisticsByIds(Long[] ids);

    /**
     * 删除业务95值计算任务信息
     *
     * @param id 业务95值计算任务主键
     * @return 结果
     */
    public int deleteEpsTaskStatisticsById(Long id);

    /**
     * 获取相关数据
     * @param epsTaskStatistics
     * @return
     */
    PageInfo<?> getRelateData(EpsTaskStatistics epsTaskStatistics);

    /**
     * 修改相关数据
     * @param epsTaskStatistics
     * @return
     */
    int updateRelateData(EpsTaskStatistics epsTaskStatistics);

    /**
     * 重新计算
     * @param epsTaskStatistics
     * @return
     */
    int recaculate(EpsTaskStatistics epsTaskStatistics);

    /**
     * 图形分析
     * @param epsTaskStatistics
     * @return
     */
    Map getRraphicalMsg(EpsTaskStatistics epsTaskStatistics);

    /**
     * 获取月均日95值的日期
     * @param epsTaskStatistics
     * @return
     */
    List<String> getAvgTimeList(EpsTaskStatistics epsTaskStatistics);
}
